@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 12918 2021-05-27 07:26:58Z Lavender $
+# $Id: admin.py 12941 2021-06-03 15:26:57Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2021-05-27 15:26:58 +0800 (週四, 27 五月 2021) $
-# $Revision: 12918 $
+# $Date: 2021-06-03 23:26:57 +0800 (週四, 03 六月 2021) $
+# $Revision: 12941 $
 
 from django.contrib import admin
 from django.contrib.admin.views.main import ChangeList
@@ -297,47 +297,6 @@ class MailingListIntegrationAdmin(MailingListAdmin):
 admin.site.unregister(MailingList)
 admin.site.register(MailingList, MailingListIntegrationAdmin)
 
-class AppNewsletterFilter(admin.SimpleListFilter):
-    # Human-readable title which will be displayed in the
-    # right admin sidebar just above the filter options.
-    title = _('App')
-
-    # Parameter for the filter that will be used in the URL query.
-    parameter_name = 'decade'
-
-    def lookups(self, request, model_admin):
-        """
-        Returns a list of tuples. The first element in each
-        tuple is the coded value for the option that will
-        appear in the URL query. The second element is the
-        human-readable name for the option that will appear
-        in the right sidebar.
-        """
-        appTuple = []
-        apps = App.objects.all()
-        for app in apps:
-            appName = app.name
-            appId = app.id
-            appTuple.append((appId, appName,))
-        return appTuple
-
-    def queryset(self, request, queryset):
-        """
-        Returns the filtered queryset based on the value
-        provided in the query string and retrievable via
-        `self.value()`.
-        """
-        # Compare the requested value (either '80s' or '90s')
-        # to decide how to filter the queryset.
-        appId = self.value()
-        if appId:
-            appNewsletterList = AppNewsletter.objects.filter(app_id=appId)
-            appNewsletterList = appNewsletterList.values_list(
-                'newsletter', flat=True)
-            return Newsletter.objects.filter(id__in=appNewsletterList)
-        else:
-            return Newsletter.objects.all()
-
 class NewsletterIntegrationChangeList(ChangeList):
     def __init__(self, request, *args, **kwargs):
         self._user = request.user
@@ -394,7 +353,7 @@ class NewsletterIntegrationChangeList(ChangeList):
 class NewsletterIntegrationAdmin(NewsletterStatisticsAdmin):
     
     list_filter = (
-        'status', 'sending_date', 'creation_date', 'modification_date',
+        'status', 'sending_date', 'creation_date', 'modification_date', 
     )
     form = NewsletterIntegrationForm
     class Media:
