@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12366 2020-06-19 06:41:16Z Andy $
+# $Id: views.py 12980 2021-06-16 13:47:53Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2020-06-19 14:41:16 +0800 (週五, 19 六月 2020) $
-# $Revision: 12366 $
+# $Author: Lavender $
+# $Date: 2021-06-16 21:47:53 +0800 (週三, 16 六月 2021) $
+# $Revision: 12980 $
 
 import base64
 from datetime import datetime
@@ -294,7 +294,7 @@ def mail(request):
                 if (_k.startswith('attachmentContent')) or (
                     _k.startswith('attachmentName')) or (
                     _k.startswith('attachmentType')):
-                    _d = unquote(_d)
+                    _d = unquote(_d.decode())
                     attachDict[_k] = _d
 
             for aId in attachmentIds:
