@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11616 2019-06-07 02:15:46Z Andy $
+# $Id: __init__.py 12803 2021-03-18 07:29:01Z Lavender $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2019-06-07 11:15:46 +0900 (週五, 07 六月 2019) $
-# $Revision: 11616 $
+# $Author: Lavender $
+# $Date: 2021-03-18 15:29:01 +0800 (週四, 18 三月 2021) $
+# $Revision: 12803 $
 
 from django.conf.urls import url
 
@@ -28,5 +28,9 @@ urlpatterns = [
         name="Theophrastus.newsletter_extension.views.getSlugName"),
     url(r'^mailingList/get/$', views.getMailingListInfo,
         name="Theophrastus.newsletter_extension.views.getMailingListInfo"),
+        
+    # black contact
+    url(r'^blackcontact/search/$', views.BlackContactSearchView.as_view()),
+    url(r'^blackcontact/add/$', views.BlackContactAddView.as_view()),
 ]
 
