@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12366 2020-06-19 06:41:16Z Andy $
+# $Id: views.py 12823 2021-03-31 12:51:48Z Lavender $
 #
 # Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
+# $Author: Lavender $
 # $Date: 2013-01-30 12:13:45 +0800$
-# $Revision: 12366 $
+# $Revision: 12823 $
+
+import json
 
 from django.shortcuts import render_to_response, get_object_or_404
 from django.utils.translation import ugettext_lazy as _
@@ -26,14 +28,19 @@ from django.conf import settings
 from django.contrib.admin.views.decorators import staff_member_required
 from django.template import RequestContext
 from django.contrib.auth.decorators import login_required
+from django.http import JsonResponse
+from django.views import View
+from django.utils.decorators import method_decorator
+from django.utils import timezone
 
 
 from Iuppiter.extension.views import jsonpCallback
 
+from emencia.django.newsletter.mailer import Mailer
 from emencia.django.newsletter.models import Newsletter, MailingList, \
                                              ContactMailingStatus, Contact
 
-from Theophrastus.newsletter_extension.models import Header, Footer
+from Theophrastus.newsletter_extension.models import Header, Footer, BlackContact
 from Theophrastus.Utility import _slugify
 
 @staff_member_required
@@ -171,3 +178,91 @@ def getFooterContent(newsletter):
         return Template(_content)
     except:
         return None
+        
+
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3496#comment:3 
+def getExpeditionList(self):
+    """Build the expedition list"""
+    credits = self.newsletter.server.credits()
+    if self.test:
+        return self.newsletter.test_contacts.all()[:credits]
+
+    blacklist = BlackContact.objects.all().values_list('email', flat=True)
+    alreadySent = ContactMailingStatus.objects.filter(
+        status=ContactMailingStatus.SENT,
+        newsletter=self.newsletter).values_list('contact__id', flat=True)
+    expeditionList = self.newsletter.mailing_list.expedition_set().exclude(
+        id__in=alreadySent
+    ).exclude(email__in=blacklist)
+    return expeditionList[:credits]
+    
+Mailer.get_expedition_list = getExpeditionList
+
+@method_decorator(csrf_exempt, name='dispatch')       
+class BlackContactSearchView(View):
+
+    def post(self, request, *args, **kwargs):
+        try:
+            emails = request.POST.getlist("emails", [])
+            blacklist = BlackContact.objects.filter(email__in=emails)
+            payload = {
+                "results": [
+                
+                ],
+            }
+            for bc in blacklist:
+                payload["results"].append({
+                    "email": bc.email,
+                    "reason": bc.reason,
+                    "createdTime": bc.createdTime,
+                    "source": bc.source,
+                    "mail": bc.mail,
+                })
+            return JsonResponse(payload)
+        except Exception as e:
+            return JsonResponse({"error": str(e)})
+
+@method_decorator(csrf_exempt, name='dispatch')        
+class BlackContactAddView(View):
+
+    def post(self, request, *args, **kwargs):
+        try:
+            emails = json.loads(request.body)
+            payload = {
+                "results": [
+                
+                ],
+            }
+            for email, data in emails.items():
+                bc, created = BlackContact.objects.get_or_create(
+                    email=email, 
+                    defaults={
+                        "reason": data.get("reason", "API"),
+                        "createdTime": timezone.now(),
+                        "source": data.get("source"),
+                        "mail": data.get("mail"),
+                    }
+                )
+                
+                if created:
+                    payload["results"].append({
+                        "email": bc.email,
+                        "reason": bc.reason,
+                        "source": bc.source,
+                        "mail": bc.mail,
+                        "createdTime": bc.createdTime,
+                        "existed": not created,
+                    })
+                else:
+                    payload["results"].append({
+                        "email": bc.email,
+                        "reason": bc.reason,
+                        "source": bc.source,
+                        "mail": bc.mail,
+                        "createdTime": bc.createdTime,
+                        "existed": not created,
+                    })
+            return JsonResponse(payload)
+        except Exception as e:
+            return JsonResponse({"error": str(e)})
+        
\ No newline at end of file
